@@ -56,7 +56,7 @@ RSpec.describe Adapter::Polling do
 
       it 'notifies change on every listener directories path' do
         expect(snapshot).to receive(:invalidate).
-          with(:dir, '.', recursive: true)
+          with(:dir, '.', { recursive: true })
 
         t = Thread.new { subject.start }
         sleep 0.25
